Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1871)

Unified Diff: chrome/browser/win/jumplist.cc

Issue 2812983005: Revert some jumplist function names (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/win/jumplist.h ('k') | chrome/browser/win/jumplist_file_util.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/win/jumplist.cc
diff --git a/chrome/browser/win/jumplist.cc b/chrome/browser/win/jumplist.cc
index 071087a3db853eaa28f52a2a835f809db9bf2b44..d9122ccf78368e3f2cee740e0cc53e2616ce8d64 100644
--- a/chrome/browser/win/jumplist.cc
+++ b/chrome/browser/win/jumplist.cc
@@ -231,11 +231,10 @@ bool UpdateJumpList(const wchar_t* app_id,
}
// Updates the jumplist, once all the data has been fetched.
-void RunUpdateJumpListUserVisiblePriority(
- IncognitoModePrefs::Availability incognito_availability,
- const std::wstring& app_id,
- const base::FilePath& icon_dir,
- base::RefCountedData<JumpListData>* ref_counted_data) {
+void RunUpdateJumpList(IncognitoModePrefs::Availability incognito_availability,
+ const std::wstring& app_id,
+ const base::FilePath& icon_dir,
+ base::RefCountedData<JumpListData>* ref_counted_data) {
JumpListData* data = &ref_counted_data->data;
ShellLinkItemList local_most_visited_pages;
ShellLinkItemList local_recently_closed_pages;
@@ -508,7 +507,7 @@ void JumpList::StartLoadingFavicon() {
if (!waiting_for_icons) {
// No more favicons are needed by the application JumpList. Schedule a
- // RunUpdateJumpListUserVisiblePriority call.
+ // RunUpdateJumpList call.
PostRunUpdate();
return;
}
@@ -534,7 +533,7 @@ void JumpList::OnFaviconDataAvailable(
JumpListData* data = &jumplist_data_->data;
base::AutoLock auto_lock(data->list_lock_);
// Attach the received data to the ShellLinkItem object.
// This data will be decoded by the RunUpdateJumpListUserVisiblePriority
// method.
if (!image_result.image.IsEmpty() && !data->icon_urls_.empty() &&
data->icon_urls_.front().second.get()) {
@@ -596,15 +595,13 @@ void JumpList::DeferredRunUpdate() {
// Post a task to delete the content in JumpListIcons folder and log the
// results to UMA.
update_jumplisticons_task_runner_->PostTask(
- FROM_HERE,
- base::Bind(&DeleteDirectoryContentAndLogResultsUserVisiblePriority,
- icon_dir_, kFileDeleteLimit));
+ FROM_HERE, base::Bind(&DeleteDirectoryContentAndLogResults, icon_dir_,
+ kFileDeleteLimit));
// Post a task to update the jumplist used by the shell.
update_jumplisticons_task_runner_->PostTask(
- FROM_HERE,
- base::Bind(&RunUpdateJumpListUserVisiblePriority, incognito_availability,
- app_id_, icon_dir_, base::RetainedRef(jumplist_data_)));
+ FROM_HERE, base::Bind(&RunUpdateJumpList, incognito_availability, app_id_,
+ icon_dir_, base::RetainedRef(jumplist_data_)));
// Post a task to delete JumpListIconsOld folder and log the results to UMA.
base::FilePath icon_dir_old = icon_dir_.DirName().Append(
« no previous file with comments | « chrome/browser/win/jumplist.h ('k') | chrome/browser/win/jumplist_file_util.h » ('j') | no next file with comments »
@@ -534,7 +533,7 @@ void JumpList::OnFaviconDataAvailable(
base::AutoLock auto_lock(data->list_lock_);
// Attach the received data to the ShellLinkItem object.
- // This data will be decoded by the RunUpdateJumpListUserVisiblePriority
+ // This data will be decoded by the RunUpdateJumpList
// method.
if (!image_result.image.IsEmpty() && !data->icon_urls_.empty() &&

Powered by Google App Engine
This is Rietveld 408576698